@@ -17,17 +17,13 @@
         'warn' => 'Unknown parameter'
       }
     ],
-    'class_description' => "A unit configuration file encodes information about a
-service, a socket, a device, a mount point, an automount point, a
-swap file or partition, a start-up target, a watched file system
-path, a timer controlled and supervised by
-L<systemd(1)>,
-a resource management slice or
-a group of externally created processes. The syntax is inspired by
-XDG
-Desktop Entry Specification .desktop
-files, which are in turn inspired by Microsoft Windows
-.ini files.
+    'class_description' => "A unit file is a plain text ini-style file that encodes information about a service, a
+socket, a device, a mount point, an automount point, a swap file or partition, a start-up
+target, a watched file system path, a timer controlled and supervised by
+L<systemd(1)>, a
+resource management slice or a group of externally created processes. See
+L<systemd.syntax(5)>
+for a general description of the syntax.
 
 This man page lists the common configuration options of all
 the unit types. These options need to be configured in the [Unit]
@@ -50,18 +46,17 @@ L<systemd.slice(5)>,
 L<systemd.scope(5)>.
 
 
-Various settings are allowed to be specified more than once,
-in which case the interpretation depends on the setting. Often,
-multiple settings form a list, and setting to an empty value
-\"resets\", which means that previous assignments are ignored. When
-this is allowed, it is mentioned in the description of the
-setting. Note that using multiple assignments to the same value
-makes the unit file incompatible with parsers for the XDG
-.desktop file format.
-
 Unit files are loaded from a set of paths determined during
 compilation, described in the next section.
 
+Unit files can be parameterized by a single argument called the \"instance name\". The unit
+is then constructed based on a \"template file\" which serves as the definition of multiple
+services or other units. A template unit must have a single C<\@> at the end of
+the name (right before the type suffix). The name of the full unit is formed by inserting the
+instance name between C<\@> and the unit type suffix. In the unit file itself,
+the instance parameter may be referred to using C<%i> and other specifiers, see
+below.
+
 Unit files may contain additional options on top of those
 listed here. If systemd encounters an unknown option, it will
 write a warning log message but continue loading the unit. If an
@@ -87,11 +82,6 @@ C<s>, C<min>, C<h>, C<d>,
 C<w>, C<ms>, C<us>.  For details see
 L<systemd.time(7)>.
 
-Empty lines and lines starting with C<#> or C<;> are
-ignored. This may be used for commenting. Lines ending in a backslash are concatenated with the
-following line while reading and the backslash is replaced by a space character. This may be
-used to wrap long lines.
-
 Units can be aliased (have an alternative name), by creating a symlink from the new name
 to the existing name in one of the unit search paths. For example,
 systemd-networkd.service has the alias
@@ -122,15 +112,24 @@ functionality exists for C<Requires> type dependencies as well, the directory
 suffix is .requires/ in this case.
 
 Along with a unit file foo.service, a \"drop-in\" directory
-foo.service.d/ may exist. All files with the suffix
-C<.conf> from this directory will be parsed after the file itself is
-parsed. This is useful to alter or add configuration settings for a unit, without having to
-modify unit files. Each drop-in file must have appropriate section headers. Note that for
-instantiated units, this logic will first look for the instance C<.d/>
-subdirectory and read its C<.conf> files, followed by the template
-C<.d/> subdirectory and the C<.conf> files there.
+foo.service.d/ may exist. All files with the suffix C<.conf> from this
+directory will be parsed after the unit file itself is parsed. This is useful to alter or add configuration
+settings for a unit, without having to modify unit files. Drop-in files must contain appropriate section
+headers. For instantiated units, this logic will first look for the instance C<.d/> subdirectory
+(e.g. C<foo\@bar.service.d/>) and read its C<.conf> files, followed by the template
+C<.d/> subdirectory (e.g. C<foo\@.service.d/>) and the C<.conf>
+files there. Moreover for units names containing dashes (C<->), the set of directories generated by
+truncating the unit name after all dashes is searched too. Specifically, for a unit name
+foo-bar-baz.service not only the regular drop-in directory
+foo-bar-baz.service.d/ is searched but also both foo-bar-.service.d/ and
+foo-.service.d/. This is useful for defining common drop-ins for a set of related units, whose
+names begin with a common prefix. This scheme is particularly useful for mount, automount and slice units, whose
+systematic naming structure is built around dashes as component separators. Note that equally named drop-in files
+further down the prefix hierarchy override those further up,
+i.e. foo-bar-.service.d/10-override.conf overrides
+foo-.service.d/10-override.conf.
 
-In addition to /etc/systemd/system, the drop-in C<.d>
+In addition to /etc/systemd/system, the drop-in C<.d/>
 directories for system services can be placed in /usr/lib/systemd/system or
 /run/systemd/system directories. Drop-in files in /etc
 take precedence over those in /run which in turn take precedence over those
@@ -144,21 +143,15 @@ sparingly and instead rely on techniques such as bus-based or
 socket-based activation which make dependencies implicit,
 resulting in a both simpler and more flexible system.
 
-Optionally, units may be instantiated from a
-template file at runtime. This allows creation of
-multiple units from a single configuration file. If
-systemd looks for a unit configuration file, it will
-first search for the literal unit name in the
-file system. If that yields no success and the unit
-name contains an C<\@> character, systemd will look for a
-unit template that shares the same name but with the
-instance string (i.e. the part between the C<\@> character
-and the suffix) removed. Example: if a service
-getty\@tty3.service is requested
-and no file by that name is found, systemd will look
-for getty\@.service and
-instantiate a service from that configuration file if
-it is found.
+As mentioned above, a unit may be instantiated from a template file. This allows creation
+of multiple units from a single configuration file. If systemd looks for a unit configuration
+file, it will first search for the literal unit name in the file system. If that yields no
+success and the unit name contains an C<\@> character, systemd will look for a
+unit template that shares the same name but with the instance string (i.e. the part between the
+C<\@> character and the suffix) removed. Example: if a service
+getty\@tty3.service is requested and no file by that name is found, systemd
+will look for getty\@.service and instantiate a service from that
+configuration file if it is found.
 
 To refer to the instance string from within the
 configuration file you may use the special C<%i>
@@ -179,7 +172,7 @@ Stability Promise.
 The set of load paths for the user manager instance may be augmented or
 changed using various environment variables. And environment variables may in
 turn be set using environment generators, see
-L<system.environment-generator(7)>.
+L<systemd.environment-generator(7)>.
 In particular, C<\$XDG_DATA_HOME> and
 C<\$XDG_DATA_DIRS> may be easily set using
 L<systemd-environment-d-generator(8)>.
@@ -282,10 +275,12 @@ above.",
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
-        'description' => 'Similar to C<Requires>.
-However, if the units listed here are not started already,
-they will not be started and the transaction will fail
-immediately.
+        'description' => 'Similar to C<Requires>. However, if the units listed here
+are not started already, they will not be started and the starting of this unit will fail
+immediately. C<Requisite> does not imply an ordering dependency, even if
+both units are started in the same transaction. Hence this setting should usually be
+combined with C<After>, to ensure this unit is not started before the other
+unit.
 
 When C<Requisite=b.service> is used on
 a.service, this dependency will show as
@@ -1098,15 +1093,13 @@ doesn't require its functionality. Use the various C<AssertArchitecture=>,
 C<AssertVirtualization=>, \x{2026} options for a similar mechanism that puts the unit in a failure
 state and logs about the failed check (see below).
 
-C<ConditionSecurity=> may be used to
-check whether the given security module is enabled on the
+C<ConditionSecurity=> may be used to check
+whether the given security technology is enabled on the
 system. Currently, the recognized values are
-C<selinux>,
-C<apparmor>,
-C<tomoyo>,
-C<ima>,
-C<smack> and
-C<audit>. The test may be negated by
+C<selinux>, C<apparmor>,
+C<tomoyo>, C<ima>,
+C<smack>, C<audit> and
+C<uefi-secureboot>. The test may be negated by
 prepending an exclamation mark.
 
 If multiple conditions are specified, the unit will be
